@@ -4,6 +4,6 @@
 ##Base:
 import os
 
-__all__ = ["DEBUG"]
+__all__ = ["FORMDEBUG"]
 
-DEBUG = True
\ No newline at end of file
+FORMDEBUG = True
